@@ -1,4 +1,4 @@
-/* $Id: chars.c,v 1.34 2005/03/20 07:24:49 dolorous Exp $ */
+/* $Id: chars.c,v 1.36 2005/03/26 06:54:36 dolorous Exp $ */
 /**************************************************************************
  *   chars.c                                                              *
  *                                                                        *
@@ -278,7 +278,7 @@ char *make_mbchar(int chr, int *chr_mb_len)
 {
     char *chr_mb;
 
-    assert(chr_mb != NULL && chr_mb_len != NULL);
+    assert(chr_mb_len != NULL);
 
 #ifdef NANO_WIDE
     if (!ISSET(NO_UTF8)) {
@@ -455,7 +455,7 @@ size_t move_mbleft(const char *buf, size_t pos)
 {
     size_t pos_prev = pos;
 
-    assert(str != NULL && pos <= strlen(buf));
+    assert(buf != NULL && pos <= strlen(buf));
 
     /* There is no library function to move backward one multibyte
      * character.  Here is the naive, O(pos) way to do it. */
