@@ -1,4 +1,4 @@
-/* $Id: files.c,v 1.136 2005/03/17 19:10:29 dolorous Exp $ */
+/* $Id: files.c,v 1.142 2005/03/31 17:00:43 dolorous Exp $ */
 /**************************************************************************
  *   files.c                                                              *
  *                                                                        *
@@ -89,7 +89,7 @@ filestruct *read_line(char *buf, filestruct *prev, bool *first_line_ins,
 	fileptr->prev = NULL;
 	fileptr->next = fileage;
 	fileptr->lineno = 1;
-	if (*first_line_ins) {
+	if (*first_line_ins == TRUE) {
 	    *first_line_ins = FALSE;
 	    /* If we're inserting into the first line of the file, then
 	     * we want to make sure that our edit buffer stays on the
@@ -100,6 +100,7 @@ filestruct *read_line(char *buf, filestruct *prev, bool *first_line_ins,
 	fileage = fileptr;
     } else {
 	assert(prev != NULL);
+
 	fileptr->prev = prev;
 	fileptr->next = NULL;
 	fileptr->lineno = prev->lineno + 1;
@@ -556,8 +557,7 @@ void do_insertfile(
 #ifdef ENABLE_MULTIBUFFER
 		&& !ISSET(MULTIBUFFER)
 #endif
-		))
-	{
+		)) {
 	    statusbar(_("Cancelled"));
 	    break;
 	} else {
@@ -580,6 +580,7 @@ void do_insertfile(
 
 		if (tmp == NULL)
 		    continue;
+
 		free(answer);
 		answer = tmp;
 
@@ -596,6 +597,15 @@ void do_insertfile(
 	    }
 #endif
 
+	    /* If we don't have a file yet, go back to the statusbar
+	     * prompt. */
+	    if (i != 0
+#ifdef ENABLE_MULTIBUFFER
+		&& (i != -2 || !ISSET(MULTIBUFFER))
+#endif
+		)
+		continue;
+
 #ifdef ENABLE_MULTIBUFFER
 	    if (!ISSET(MULTIBUFFER)) {
 #endif
@@ -982,15 +992,8 @@ char *get_full_path(const char *origpath)
     	return NULL;
 
     /* Get the current directory. */
-#if PATH_MAX != -1
     d_here = charalloc(PATH_MAX + 1);
-#else
-    d_here = NULL;
-#endif
     d_here = getcwd(d_here, PATH_MAX + 1);
-#if PATH_MAX != -1
-    align(&d_here);
-#endif
 
     if (d_here != NULL) {
 	const char *last_slash;
@@ -998,6 +1001,8 @@ char *get_full_path(const char *origpath)
 	bool path_only;
 	struct stat fileinfo;
 
+	align(&d_here);
+
 	/* If the current directory isn't "/", tack a slash onto the end
 	 * of it. */
 	if (strcmp(d_here, "/") != 0) {
@@ -1054,26 +1059,24 @@ char *get_full_path(const char *origpath)
 	    } else {
 		/* Get the full path and save it in d_there. */
 		free(d_there);
-#if PATH_MAX != -1
-		d_there = charalloc(PATH_MAX + 1);
-#else
-		d_there = NULL;
-#endif
-		d_there = getcwd(d_there, PATH_MAX + 1);
-#if PATH_MAX != -1
-		align(&d_there);
-#endif
 
-		if (d_there == NULL)
+		d_there = charalloc(PATH_MAX + 1);
+		d_there = getcwd(d_there, PATH_MAX + 1);
+
+		if (d_there != NULL) {
+		    align(&d_there);
+
+		    if (strcmp(d_there, "/") != 0) {
+			/* Make sure d_there ends in a slash. */
+			d_there = charealloc(d_there,
+				strlen(d_there) + 2);
+			strcat(d_there, "/");
+		    }
+		} else
 		    /* If we couldn't get the full path, set path_only
 		     * to TRUE so that we clean up correctly, free all
 		     * allocated memory, and return NULL. */
 		    path_only = TRUE;
-		else if (strcmp(d_there, "/") != 0) {
-		    /* Make sure d_there ends in a slash. */
-		    d_there = charealloc(d_there, strlen(d_there) + 2);
-		    strcat(d_there, "/");
-		}
 
 		/* Finally, go back to the path specified in d_here,
 		 * where we were before. */
@@ -1089,7 +1092,7 @@ char *get_full_path(const char *origpath)
 	 * d_there_file contains the filename portion of the answer.  If
 	 * this is the case, tack d_there_file onto the end of
 	 * d_there, so that d_there contains the complete answer. */
-	if (!path_only && d_there) {
+	if (!path_only && d_there != NULL) {
 	    d_there = charealloc(d_there, strlen(d_there) +
 		strlen(d_there_file) + 1);
 	    strcat(d_there, d_there_file);
@@ -1340,6 +1343,7 @@ int write_file(const char *name, bool tmp, int append, bool
 	/* The temp file name we write to on prepend. */
 
     assert(name != NULL);
+
     if (name[0] == '\0')
 	return -1;
     if (!tmp)
@@ -2429,7 +2433,7 @@ char *do_browser(char *path, DIR *dir)
     /* Loop invariant: Microsoft sucks. */
     do {
 	bool abort = FALSE;
-	int j, col = 0, editline = 0, lineno;
+	int j, col = 0, editline = 0, fileline;
 	int filecols = 0;
 	    /* Used only if width == 0, to calculate the number of files
 	     * per row below. */
@@ -2444,9 +2448,9 @@ char *do_browser(char *path, DIR *dir)
 
 	/* Compute the line number we're on now, so that we don't divide
 	 * by zero later. */
-	lineno = selected;
+	fileline = selected;
 	if (width != 0)
-	    lineno /= width;
+	    fileline /= width;
 
 	switch (kbinput) {
 #ifndef DISABLE_MOUSE
@@ -2463,7 +2467,7 @@ char *do_browser(char *path, DIR *dir)
 
 		    /* longest is the width of each column.  There are
 		     * two spaces between each column. */
-		    selected = (lineno / editwinrows) * editwinrows *
+		    selected = (fileline / editwinrows) * editwinrows *
 			width + mevent.y * width + mevent.x /
 			(longest + 2);
 
@@ -2508,9 +2512,9 @@ char *do_browser(char *path, DIR *dir)
 	    case NANO_PREVPAGE_KEY:
 	    case NANO_PREVPAGE_FKEY:
 	    case '-': /* Pico compatibility. */
-		if (selected >= (editwinrows + lineno % editwinrows) *
+		if (selected >= (editwinrows + fileline % editwinrows) *
 			width)
-		    selected -= (editwinrows + lineno % editwinrows) *
+		    selected -= (editwinrows + fileline % editwinrows) *
 			width;
 		else
 		    selected = 0;
@@ -2518,7 +2522,7 @@ char *do_browser(char *path, DIR *dir)
 	    case NANO_NEXTPAGE_KEY:
 	    case NANO_NEXTPAGE_FKEY:
 	    case ' ': /* Pico compatibility. */
-		selected += (editwinrows - lineno % editwinrows) *
+		selected += (editwinrows - fileline % editwinrows) *
 			width;
 		if (selected >= numents)
 		    selected = numents - 1;
@@ -2756,14 +2760,15 @@ char *do_browser(char *path, DIR *dir)
     return retval;
 }
 
-/* Browser front end, checks to see if inpath has a dir in it and, if
-   so, starts do_browser from there, else from the current dir */
+/* The file browser front end.  We check to see if inpath has a dir in
+ * it.  If it does, we start do_browser() from there.  Otherwise, we
+ * start do_browser() from the current directory. */
 char *do_browse_from(const char *inpath)
 {
     struct stat st;
     char *path;
 	/* This holds the tilde-expanded version of inpath. */
-    DIR *dir;
+    DIR *dir = NULL;
 
     assert(inpath != NULL);
 
@@ -2779,15 +2784,12 @@ char *do_browse_from(const char *inpath)
 	striponedir(path);
 	if (stat(path, &st) == -1 || !S_ISDIR(st.st_mode)) {
 	    free(path);
-#if PATH_MAX != -1
+
 	    path = charalloc(PATH_MAX + 1);
-#else
-	    path = NULL;
-#endif
 	    path = getcwd(path, PATH_MAX + 1);
-#if PATH_MAX != -1
-	    align(&path);
-#endif
+
+	    if (path != NULL)
+		align(&path);
 	}
     }
 
@@ -2801,7 +2803,9 @@ char *do_browse_from(const char *inpath)
     }
 #endif
 
-    dir = opendir(path);
+    if (path != NULL)
+	dir = opendir(path);
+
     if (dir == NULL) {
 	beep();
 	free(path);
