@@ -1,8 +1,8 @@
-/* $Id: move.c,v 1.15 2004/11/17 23:17:05 jordi Exp $ */
+/* $Id: move.c,v 1.26 2005/03/09 20:35:10 dolorous Exp $ */
 /**************************************************************************
  *   move.c                                                               *
  *                                                                        *
- *   Copyright (C) 1999-2004 Chris Allegretta                             *
+ *   Copyright (C) 1999-2005 Chris Allegretta                             *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 2, or (at your option)  *
@@ -32,37 +32,36 @@
 
 void do_first_line(void)
 {
-    size_t old_pww = placewewant;
+    size_t pww_save = placewewant;
     current = fileage;
     placewewant = 0;
     current_x = 0;
-    if (edittop != fileage || need_vertical_update(old_pww))
+    if (edittop != fileage || need_vertical_update(pww_save))
 	edit_update(TOP);
 }
 
 void do_last_line(void)
 {
-    size_t old_pww = placewewant;
+    size_t pww_save = placewewant;
     current = filebot;
     placewewant = 0;
     current_x = 0;
     if (edittop->lineno + (editwinrows / 2) != filebot->lineno ||
-	need_vertical_update(old_pww))
+	need_vertical_update(pww_save))
 	edit_update(CENTER);
 }
 
 void do_home(void)
 {
-    size_t old_pww = placewewant;
+    size_t pww_save = placewewant;
 #ifndef NANO_SMALL
     if (ISSET(SMART_HOME)) {
-	size_t old_current_x = current_x;
+	size_t current_x_save = current_x;
 
-	for (current_x = 0; isblank(current->data[current_x]) &&
-		current->data[current_x] != '\0'; current_x++)
-	    ;
+	current_x = indent_length(current->data);
 
-	if (current_x == old_current_x || current->data[current_x] == '\0')
+	if (current_x == current_x_save ||
+		current->data[current_x] == '\0')
 	    current_x = 0;
 
 	placewewant = xplustabs();
@@ -74,24 +73,24 @@ void do_home(void)
     }
 #endif
     check_statusblank();
-    if (need_horizontal_update(old_pww))
+    if (need_horizontal_update(pww_save))
 	update_line(current, current_x);
 }
 
 void do_end(void)
 {
-    size_t old_pww = placewewant;
+    size_t pww_save = placewewant;
     current_x = strlen(current->data);
     placewewant = xplustabs();
     check_statusblank();
-    if (need_horizontal_update(old_pww))
+    if (need_horizontal_update(pww_save))
 	update_line(current, current_x);
 }
 
 void do_page_up(void)
 {
-    size_t old_pww = placewewant;
-    const filestruct *old_current = current;
+    size_t pww_save = placewewant;
+    const filestruct *current_save = current;
 #ifndef DISABLE_WRAPPING
     wrap_reset();
 #endif
@@ -129,15 +128,15 @@ void do_page_up(void)
     current_x = actual_x(current->data, placewewant);
 
     /* Update all the lines that need to be updated. */
-    edit_redraw(old_current, old_pww);
+    edit_redraw(current_save, pww_save);
 
     check_statusblank();
 }
 
 void do_page_down(void)
 {
-    size_t old_pww = placewewant;
-    const filestruct *old_current = current;
+    size_t pww_save = placewewant;
+    const filestruct *current_save = current;
 #ifndef DISABLE_WRAPPING
     wrap_reset();
 #endif
@@ -176,7 +175,7 @@ void do_page_down(void)
     current_x = actual_x(current->data, placewewant);
 
     /* Update all the lines that need to be updated. */
-    edit_redraw(old_current, old_pww);
+    edit_redraw(current_save, pww_save);
 
     check_statusblank();
 }
@@ -192,6 +191,7 @@ void do_up(void)
 	return;
 
     assert(current_y == current->lineno - edittop->lineno);
+
     current = current->prev;
     current_x = actual_x(current->data, placewewant);
 
@@ -247,18 +247,18 @@ void do_down(void)
     update_line(current, current_x);
 }
 
-void do_left(int allow_update)
+void do_left(bool allow_update)
 {
-    size_t old_pww = placewewant;
+    size_t pww_save = placewewant;
     if (current_x > 0)
-	current_x--;
+	current_x = move_mbleft(current->data, current_x);
     else if (current != fileage) {
 	do_up();
 	current_x = strlen(current->data);
     }
     placewewant = xplustabs();
     check_statusblank();
-    if (allow_update && need_horizontal_update(old_pww))
+    if (allow_update && need_horizontal_update(pww_save))
 	update_line(current, current_x);
 }
 
@@ -267,20 +267,20 @@ void do_left_void(void)
     do_left(TRUE);
 }
 
-void do_right(int allow_update)
+void do_right(bool allow_update)
 {
-    size_t old_pww = placewewant;
+    size_t pww_save = placewewant;
     assert(current_x <= strlen(current->data));
 
     if (current->data[current_x] != '\0')
-	current_x++;
+	current_x = move_mbright(current->data, current_x);
     else if (current->next != NULL) {
 	do_down();
 	current_x = 0;
     }
     placewewant = xplustabs();
     check_statusblank();
-    if (allow_update && need_horizontal_update(old_pww))
+    if (allow_update && need_horizontal_update(pww_save))
 	update_line(current, current_x);
 }
 
