@@ -1,4 +1,4 @@
-/* $Id: nano.h,v 1.85 2005/03/20 07:24:49 dolorous Exp $ */
+/* $Id: nano.h,v 1.90 2005/03/26 04:42:28 dolorous Exp $ */
 /**************************************************************************
  *   nano.h                                                               *
  *                                                                        *
@@ -46,15 +46,16 @@
 #define charmove(dest, src, n) memmove(dest, src, (n) * sizeof(char))
 #define charcpy(dest, src, n) memcpy(dest, src, (n) * sizeof(char))
 
+/* Other macros. */
 #ifdef BROKEN_REGEXEC
 #undef regexec
-#define regexec(preg, string, nmatch, pmatch, eflags) regexec_safe(preg, string, nmatch, pmatch, eflags)
+#define regexec(preg, string, nmatch, pmatch, eflags) safe_regexec(preg, string, nmatch, pmatch, eflags)
 #endif
 
 /* Set a default value for PATH_MAX, so we can use it in lines like
  * "path = getcwd(NULL, PATH_MAX + 1);". */
 #ifndef PATH_MAX
-#define PATH_MAX -1
+#define PATH_MAX 4096
 #endif
 
 #ifdef USE_SLANG
@@ -82,7 +83,7 @@
 #endif
 #define gettext_noop(string) (string)
 #define N_(string) gettext_noop(string)
-	/* Mark a string that will be sent to gettext later. */
+	/* Mark a string that will be sent to gettext() later. */
 
 #include <stddef.h>
 #include <sys/types.h>
@@ -121,11 +122,6 @@
 #define getline ngetline
 #endif
 
-/* Assume ERR is defined as -1.  To avoid duplicate case values when
- * some key definitions are missing, we have to set all of these, and
- * all of the special sentinel values below, to different negative
- * values other than -1. */
-
 #define VERMSG "GNU nano " VERSION
 
 /* If we aren't using ncurses, turn the mouse support off, as it's
@@ -239,24 +235,28 @@ typedef struct rcoption {
 
 #ifdef ENABLE_COLOR
 typedef struct colortype {
-    int fg;			/* fg color */
-    int bg;			/* bg color */
+    int fg;			/* Foreground color. */
+    int bg;			/* Background color. */
     int bright;			/* Is this color A_BOLD? */
-    int pairnum;		/* Color pair number used for this fg/bg */
-    regex_t start;		/* Start (or all) of the regex string */
-    regex_t *end;		/* End of the regex string */
+    int pairnum;		/* Color pair number used for this
+				 * foreground/background. */
+    regex_t start;		/* Start (or all) of the regex
+				 * string. */
+    regex_t *end;		/* End (if any) of the regex string. */
     struct colortype *next;
 } colortype;
 
 typedef struct exttype {
-    regex_t val;		/* The extensions that match this syntax. */
+    regex_t val;		/* The extensions that match this
+				 * syntax. */
     struct exttype *next;
 } exttype;
 
 typedef struct syntaxtype {
-    char *desc;			/* Name of this syntax type */
-    exttype *extensions;	/* List of extensions that this applies to */
-    colortype *color;		/* color struct for this syntax */
+    char *desc;			/* Name of this syntax type. */
+    exttype *extensions;	/* List of extensions that this syntax
+				 * applies to. */
+    colortype *color;		/* Color struct for this syntax. */
     struct syntaxtype *next;
 } syntaxtype;
 #endif
@@ -271,7 +271,7 @@ typedef struct historytype {
 typedef struct historyheadtype {
     struct historytype *next;	/* Keep *next and *prev members
 				 * together. */
-    struct historytype *prev;	/* And in same order as in
+    struct historytype *prev;	/* And in the same order as in
 				 * historytype. */
     struct historytype *tail;
     struct historytype *current;
@@ -517,8 +517,7 @@ typedef struct historyheadtype {
 /* Default width of a tab. */
 #define WIDTH_OF_TAB 8
 
-/* Maximum number of search history strings saved, same value used for
- * replace history. */
+/* Maximum number of search/replace history strings saved. */
 #define MAX_SEARCH_HISTORY 100
 
 #endif /* !NANO_H */
