@@ -1,4 +1,4 @@
-/* $Id: proto.h,v 1.182 2005/03/19 21:15:30 dolorous Exp $ */
+/* $Id: proto.h,v 1.185 2005/03/26 22:49:46 dolorous Exp $ */
 /**************************************************************************
  *   proto.h                                                              *
  *                                                                        *
@@ -223,8 +223,8 @@ void cutbuffer_reset(void);
 void cut_line(void);
 #ifndef NANO_SMALL
 void cut_marked(void);
-#endif
 void cut_to_eol(void);
+#endif
 void do_cut_text(void);
 #ifndef NANO_SMALL
 void do_cut_till_end(void);
@@ -382,8 +382,11 @@ void move_to_filestruct(filestruct **file_top, filestruct **file_bot,
 void copy_from_filestruct(filestruct *file_top, filestruct *file_bot);
 void renumber_all(void);
 void renumber(filestruct *fileptr);
-void print1opt(const char *shortflag, const char *longflag, const char
-	*desc);
+void print1opt_full(const char *shortflag
+#ifdef HAVE_GETOPT_LONG
+	, const char *longflag
+#endif
+	, const char *desc);
 void usage(void);
 void version(void);
 int no_more_space(void);
@@ -532,7 +535,7 @@ void free_history(historyheadtype *h);
 /* Public functions in utils.c. */
 #ifdef HAVE_REGEX_H
 #ifdef BROKEN_REGEXEC
-int regexec_safe(const regex_t *preg, const char *string, size_t nmatch,
+int safe_regexec(const regex_t *preg, const char *string, size_t nmatch,
 	regmatch_t pmatch[], int eflags);
 #endif
 int regexp_bol_or_eol(const regex_t *preg, const char *string);
