@@ -1,4 +1,4 @@
-/* $Id: rcfile.c,v 1.48 2005/03/14 18:47:21 dolorous Exp $ */
+/* $Id: rcfile.c,v 1.49 2005/03/27 01:34:40 dolorous Exp $ */
 /**************************************************************************
  *   rcfile.c                                                             *
  *                                                                        *
@@ -650,7 +650,7 @@ void parse_rcfile(FILE *rcstream)
 			    assert(FALSE);
 		    }
 #ifdef DEBUG
-		    fprintf(stderr, "flag = %d\n", rcopts[i].flag);
+		    fprintf(stderr, "flag = %ld\n", rcopts[i].flag);
 #endif
 		} else if (rcopts[i].flag != 0)
 		    UNSET(rcopts[i].flag);
