@@ -1,8 +1,8 @@
-/* $Id: search.c,v 1.80 2004/11/22 17:08:41 dolorous Exp $ */
+/* $Id: search.c,v 1.93 2005/03/14 19:17:27 dolorous Exp $ */
 /**************************************************************************
  *   search.c                                                             *
  *                                                                        *
- *   Copyright (C) 2000-2004 Chris Allegretta                             *
+ *   Copyright (C) 2000-2005 Chris Allegretta                             *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 2, or (at your option)  *
@@ -83,11 +83,11 @@ void not_found_msg(const char *str)
  
     assert(str != NULL);
 
-    disp = display_string(str, 0, (COLS / 2) + 1);
-    numchars = strnlen(disp, COLS / 2);
+    disp = display_string(str, 0, (COLS / 2) + 1, FALSE);
+    numchars = actual_x(disp, mbstrnlen(disp, COLS / 2));
 
     statusbar(_("\"%.*s%s\" not found"), numchars, disp,
-	disp[numchars] == '\0' ? "" : "...");
+	(disp[numchars] == '\0') ? "" : "...");
 
     free(disp);
 }
@@ -150,9 +150,9 @@ int search_init(bool replacing, bool use_answer)
 #endif
 
     if (last_search[0] != '\0') {
-	char *disp = display_string(last_search, 0, COLS / 3);
+	char *disp = display_string(last_search, 0, COLS / 3, FALSE);
 
-	buf = charalloc(COLS / 3 + 7);
+	buf = charalloc(strlen(disp) + 7);
 	/* We use COLS / 3 here because we need to see more on the
 	 * line. */
 	sprintf(buf, " [%s%s]", disp,
@@ -255,9 +255,9 @@ int search_init(bool replacing, bool use_answer)
 #ifndef NANO_SMALL
 		search_history.current = search_history.next;
 #endif
-		/* Put answer up on the statusbar. */
-		do_gotoline(-1, FALSE);
-		/* Fall through. */
+		do_gotoline(-1, FALSE);	/* Put answer up on the
+					 * statusbar and fall
+					 * through. */
 	    default:
 		return -1;
 	}
@@ -265,20 +265,33 @@ int search_init(bool replacing, bool use_answer)
     return 0;
 }
 
-bool is_whole_word(int curr_pos, const char *datastr, const char
-	*searchword)
+bool is_whole_word(size_t pos, const char *buf, const char *word)
 {
-    size_t sln = curr_pos + strlen(searchword);
+    char *p = charalloc(mb_cur_max()), *r = charalloc(mb_cur_max());
+    size_t word_end = pos + strlen(word);
+    bool retval;
 
-    /* Start of line or previous character is not a letter and end of
-     * line or next character is not a letter. */
-    return (curr_pos < 1 || !isalpha(datastr[curr_pos - 1])) &&
-	(sln == strlen(datastr) || !isalpha(datastr[sln]));
+    assert(buf != NULL && pos <= strlen(buf) && word != NULL);
+
+    parse_mbchar(buf + move_mbleft(buf, pos), p, NULL, NULL);
+    parse_mbchar(buf + word_end, r, NULL, NULL);
+
+    /* If we're at the beginning of the line or the character before the
+     * word isn't an alphanumeric character, and if we're at the end of
+     * the line or the character after the word isn't an alphanumeric
+     * character, we have a whole word. */
+    retval = (pos == 0 || !is_alnum_mbchar(p)) &&
+	(word_end == strlen(buf) || !is_alnum_mbchar(r));
+
+    free(p);
+    free(r);
+
+    return retval;
 }
 
-/* Look for needle, starting at current, column current_x.  If
- * no_sameline is TRUE, skip over begin when looking for needle.  begin
- * is the line where we first started searching, at column beginx.  If
+/* Look for needle, starting at (current, current_x).  If no_sameline is
+ * TRUE, skip over begin when looking for needle.  begin is the line
+ * where we first started searching, at column beginx.  If
  * can_display_wrap is TRUE, we put messages on the statusbar, wrap
  * around the file boundaries.  The return value specifies whether we
  * found anything.  If we did, set needle_len to the length of the
@@ -584,8 +597,8 @@ int replace_regexp(char *string, bool create_flag)
     while (*c != '\0') {
 	int num = (int)(*(c + 1) - '0');
 
-	if (*c != '\\' || num < 1 || num > 9 || num >
-		search_regexp.re_nsub) {
+	if (*c != '\\' || num < 1 || num > 9 ||
+		num > search_regexp.re_nsub) {
 	    if (create_flag)
 		*string++ = *c;
 	    c++;
@@ -748,7 +761,8 @@ ssize_t do_replace_loop(const char *needle, const filestruct
 	    size_t xpt = xplustabs();
 
 	    exp_word = display_string(current->data, xpt,
-		strnlenpt(current->data, match_len + current_x) - xpt);
+		strnlenpt(current->data, match_len + current_x) - xpt,
+		FALSE);
 
 	    curs_set(0);
 	    do_replace_highlight(TRUE, exp_word);
@@ -790,8 +804,8 @@ ssize_t do_replace_loop(const char *needle, const filestruct
 	     * the top of it, don't change mark_beginx. */
 	    if (!old_mark_set || !right_side_up) {
 		/* Keep mark_beginx in sync with the text changes. */
-		if (current == mark_beginbuf && mark_beginx >
-			current_x) {
+		if (current == mark_beginbuf &&
+			mark_beginx > current_x) {
 		    if (mark_beginx < current_x + match_len)
 			mark_beginx = current_x;
 		    else
@@ -804,8 +818,8 @@ ssize_t do_replace_loop(const char *needle, const filestruct
 	    if (!old_mark_set || right_side_up) {
 #endif
 		/* Keep real_current_x in sync with the text changes. */
-		if (current == real_current && current_x <=
-			*real_current_x) {
+		if (current == real_current &&
+			current_x <= *real_current_x) {
 		    if (*real_current_x < current_x + match_len)
 			*real_current_x = current_x + match_len;
 		    *real_current_x += length_change;
@@ -830,7 +844,7 @@ ssize_t do_replace_loop(const char *needle, const filestruct
 
 	    if (!replaceall) {
 #ifdef ENABLE_COLOR
-		if (ISSET(COLOR_SYNTAX))
+		if (!ISSET(NO_COLOR_SYNTAX))
 		    edit_refresh();
 		else
 #endif
@@ -1043,7 +1057,7 @@ void do_find_bracket(void)
     char regexp_pat[] = "[  ]";
     size_t current_x_save, pww_save;
     int count = 1;
-    long flags_save;
+    unsigned long flags_save;
     filestruct *current_save;
 
     ch_under_cursor = current->data[current_x];
@@ -1055,6 +1069,7 @@ void do_find_bracket(void)
     }
 
     assert(strlen(brackets) % 2 == 0);
+
     wanted_ch = brackets[(strlen(brackets) - 1) - (pos - brackets)];
 
     current_save = current;
@@ -1065,7 +1080,6 @@ void do_find_bracket(void)
 
     /* Apparent near redundancy with regexp_pat[] here is needed.
      * "[][]" works, "[[]]" doesn't. */
-
     if (pos < brackets + (strlen(brackets) / 2)) {
 	/* On a left bracket. */
 	regexp_pat[1] = wanted_ch;
@@ -1079,6 +1093,7 @@ void do_find_bracket(void)
     }
 
     regexp_init(regexp_pat);
+
     /* We constructed regexp_pat to be a valid expression. */
     assert(regexp_compiled);
 
