@@ -1,4 +1,4 @@
-/* $Id: utils.c,v 1.65 2005/02/22 23:22:37 dolorous Exp $ */
+/* $Id: utils.c,v 1.69 2005/04/08 20:06:08 dolorous Exp $ */
 /**************************************************************************
  *   utils.c                                                              *
  *                                                                        *
@@ -36,11 +36,13 @@
 
 #ifdef HAVE_REGEX_H
 #ifdef BROKEN_REGEXEC
-int regexec_safe(const regex_t *preg, const char *string, size_t nmatch,
+/* Work around a potential segfault in glibc 2.2.3's regexec(). */
+int safe_regexec(const regex_t *preg, const char *string, size_t nmatch,
 	regmatch_t pmatch[], int eflags)
 {
     if (string != NULL && *string != '\0')
 	return regexec(preg, string, nmatch, pmatch, eflags);
+
     return REG_NOMATCH;
 }
 #endif
@@ -110,6 +112,7 @@ bool parse_num(const char *str, ssize_t *val)
 void align(char **strp)
 {
     assert(strp != NULL);
+
     if (*strp != NULL)
 	*strp = charealloc(*strp, strlen(*strp) + 1);
 }
@@ -118,6 +121,7 @@ void align(char **strp)
 void null_at(char **data, size_t index)
 {
     assert(data != NULL);
+
     *data = charealloc(*data, index + 1);
     (*data)[index] = '\0';
 }
@@ -127,6 +131,7 @@ void null_at(char **data, size_t index)
 void unsunder(char *str, size_t true_len)
 {
     assert(str != NULL);
+
     for (; true_len > 0; true_len--, str++) {
 	if (*str == '\0')
 	    *str = '\n';
@@ -138,6 +143,7 @@ void unsunder(char *str, size_t true_len)
 void sunder(char *str)
 {
     assert(str != NULL);
+
     for (; *str != '\0'; str++) {
 	if (*str == '\n')
 	    *str = '\0';
@@ -217,7 +223,9 @@ const char *strstrwrapper(const char *haystack, const char *needle,
      * line.  In either case, we just say no match was found. */
     if ((start > haystack && *(start - 1) == '\0') || start < haystack)
 	return NULL;
+
     assert(haystack != NULL && needle != NULL && start != NULL);
+
 #ifdef HAVE_REGEX_H
     if (ISSET(USE_REGEXP)) {
 #ifndef NANO_SMALL
@@ -267,18 +275,19 @@ const char *strstrwrapper(const char *haystack, const char *needle,
 }
 
 /* This is a wrapper for the perror() function.  The wrapper takes care
- * of ncurses, calls perror (which writes to stderr), then refreshes the
- * screen.  Note that nperror() causes the window to flicker once. */
+ * of curses, calls perror() (which writes to stderr), and then
+ * refreshes the screen.  Note that nperror() causes the window to
+ * flicker once. */
 void nperror(const char *s)
 {
-    /* leave ncurses mode, go to the terminal */
+    /* Leave curses mode and go to the terminal. */
     if (endwin() != ERR) {
-	perror(s);		/* print the error */
-	total_refresh();	/* return to ncurses and repaint */
+	perror(s);		/* Print the error. */
+	total_refresh();	/* Return to curses and refresh. */
     }
 }
 
-/* Thanks BG, many ppl have been asking for this... */
+/* Thanks, BG, many people have been asking for this... */
 void *nmalloc(size_t howmuch)
 {
     void *r = malloc(howmuch);
